# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ...core.api_error import ApiError
from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.http_response import AsyncHttpResponse, HttpResponse
from ...core.parse_error import ParsingError
from ...core.request_options import RequestOptions
from ...core.unchecked_base_model import construct_type
from ...errors.unprocessable_entity_error import UnprocessableEntityError
from ...types.workspace_audit_logs_page_response import WorkspaceAuditLogsPageResponse
from pydantic import ValidationError


class RawAuditLogsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list(
        self,
        *,
        limit: typing.Optional[int] = None,
        cursor: typing.Optional[str] = None,
        time_from_unix_ms: typing.Optional[int] = None,
        time_to_unix_ms: typing.Optional[int] = None,
        actor_uid: typing.Optional[str] = None,
        class_name: typing.Optional[str] = None,
        activity_name: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[WorkspaceAuditLogsPageResponse]:
        """
        Returns the audit log for the workspace. Requires enterprise tier and the audit_log_read permission.

        Parameters
        ----------
        limit : typing.Optional[int]
            Maximum number of entries per page

        cursor : typing.Optional[str]
            Cursor for the next page (from previous response)

        time_from_unix_ms : typing.Optional[int]
            Only include entries at or after this time (ms since epoch)

        time_to_unix_ms : typing.Optional[int]
            Only include entries at or before this time (ms since epoch)

        actor_uid : typing.Optional[str]
            Filter by actor user ID

        class_name : typing.Optional[str]
            Filter by OCSF event class name (e.g. Account Change)

        activity_name : typing.Optional[str]
            Filter by audit activity name (e.g. Subscription Creation)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[WorkspaceAuditLogsPageResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/workspace/audit-logs",
            method="GET",
            params={
                "limit": limit,
                "cursor": cursor,
                "time_from_unix_ms": time_from_unix_ms,
                "time_to_unix_ms": time_to_unix_ms,
                "actor_uid": actor_uid,
                "class_name": class_name,
                "activity_name": activity_name,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    WorkspaceAuditLogsPageResponse,
                    construct_type(
                        type_=WorkspaceAuditLogsPageResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawAuditLogsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list(
        self,
        *,
        limit: typing.Optional[int] = None,
        cursor: typing.Optional[str] = None,
        time_from_unix_ms: typing.Optional[int] = None,
        time_to_unix_ms: typing.Optional[int] = None,
        actor_uid: typing.Optional[str] = None,
        class_name: typing.Optional[str] = None,
        activity_name: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[WorkspaceAuditLogsPageResponse]:
        """
        Returns the audit log for the workspace. Requires enterprise tier and the audit_log_read permission.

        Parameters
        ----------
        limit : typing.Optional[int]
            Maximum number of entries per page

        cursor : typing.Optional[str]
            Cursor for the next page (from previous response)

        time_from_unix_ms : typing.Optional[int]
            Only include entries at or after this time (ms since epoch)

        time_to_unix_ms : typing.Optional[int]
            Only include entries at or before this time (ms since epoch)

        actor_uid : typing.Optional[str]
            Filter by actor user ID

        class_name : typing.Optional[str]
            Filter by OCSF event class name (e.g. Account Change)

        activity_name : typing.Optional[str]
            Filter by audit activity name (e.g. Subscription Creation)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[WorkspaceAuditLogsPageResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/workspace/audit-logs",
            method="GET",
            params={
                "limit": limit,
                "cursor": cursor,
                "time_from_unix_ms": time_from_unix_ms,
                "time_to_unix_ms": time_to_unix_ms,
                "actor_uid": actor_uid,
                "class_name": class_name,
                "activity_name": activity_name,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    WorkspaceAuditLogsPageResponse,
                    construct_type(
                        type_=WorkspaceAuditLogsPageResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)
